use application "Capture One 11"

on currentDocument()
	return name of current document
end currentDocument

on variantsIn(collectionName)
	return name of every variant of collection named collectionName of current document
end variantsIn

on favoritesList()
	
	tell current document
		name of (every collection whose kind is favorite and (name is not "Capture" and name is not "Selects" and name is not "Output" and name is not "Trash"))
	end tell
	
end favoritesList

on setCapture(collectionName)
	
	set collectionPath to makeDirectoryInCapture(collectionName)
	log file (collectionPath as text)
	
	tell current document
		set captures to file (collectionPath as text)
		make new collection with properties {folder:captures, kind:favorite}
	end tell
	
	return getCapture()
	
end setCapture

on getCapture()
	
	set captureDir to captures of current document
	tell application "Finder" to set collectionName to name of (captureDir as alias)
	
	return collectionName
	
end getCapture

on makeDirectoryInCapture(name)
	
	tell current document
		
		-- Get the session Capture directory
		set captureDir to (folder as text) & "Capture"
		
		tell application "Finder"
			try
				set newDir to make new folder at captureDir with properties {name:name}
				log "Made directory " & name & " at " & captureDir
				return newDir
			on error number errorNumber
				
				if the errorNumber is equal to -48 then
					set newDir to folder (captureDir & ":" & name)
					log "Directory " & name & " exists at " & captureDir
					return newDir
				else
					log "Failed to create " & name & " at " & captureDir
				end if
				
			end try
		end tell
		
	end tell
	
end makeDirectoryInCapture

on makeDirs(dirNames)
	
	set newDirs to []
	log "Creating " & (count of dirNames) & " directories"
	repeat with newName in dirNames
		
		set newDir to makeDirectoryInCapture(newName) as text
		set newDirs to newDirs & newDir
		
		
	end repeat
	log "Created " & (count of newDirs) & " directories"
	return newDirs
end makeDirs

on addFavorites(dirPaths, setCapture)
	
	tell current document
		
		log "Adding " & (count of dirPaths) & " to favorites"
		-- Add all paths to favorites
		repeat with dirPath in dirPaths
			set captureCollection to make collection with properties {kind:favorite, file:dirPath}
			log "Added collection to favorites " & dirPath
		end repeat
		
		if setCapture is true and (count of dirPaths) is greater than 0 then
			-- Set the first item as the capture folder
			
			set captures to file (first item in dirPaths as text)
		end if
	end tell
	
	
end addFavorites

on makeDirsAndFaves(dirNames, setCapture)
	
	set fullPaths to makeDirs(dirNames)
	addFavorites(fullPaths, setCapture)
	
	tell front document of application "Capture One 20" to set captureDir to captures of current document
	tell application "Finder" to return name of (captureDir as alias)
	
end makeDirsAndFaves

--on collectionInfoCount(collectionName, smartAlbumName)
--  if application "Capture One 11" is not running then
--    error "Capture One is not running"
--  end if
--
--  tell front document of application "Capture One 11"
--    return {number of variants of collection named collectionName, my countFor(collectionName, smartAlbumName)}
--  end tell
--
--end collectionInfoCount

(*
Returns an array with
  - name
  - kind
  - folder
  - rules
  - number of variants
  - number of matched variants (if smartAlbumName is given)
*)
on collectionInfo(collectionName)
	
	tell current document
		
		set theCollection to collection named collectionName
		
		set theKind to kind of theCollection
		set theFolder to folder of theCollection
		set theRules to rules of theCollection
		set variantCount to number of variants of theCollection
		
		return {collectionName, theKind, theFolder, theRules, variantCount}
		
	end tell
	
end collectionInfo

on getCaptureName()
	return {capture name format, capture name} of current document
end getCaptureName

on setCaptureName(newFormat, newName)
	
	tell current document
		if newFormat is not missing value then
			set capture name format to newFormat
		end if
		
		if newName is not missing value then
			set capture name to newName
		end if
		
		return {capture name format, capture name}
		
	end tell
end setCaptureName

